==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Block/ts/Block_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Block</name>
    <message>
        <location filename="../Block.js" line="+67"/>
        <source>Block Tools</source>
        <translation>Strumenti di blocco</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show block tools</source>
        <translation>Mostra gli strumenti di blocco</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Block</source>
        <translation>&amp;Blocco</translation>
    </message>
</context>
<context>
    <name>BlockDialog</name>
    <message>
        <location filename="../BlockDialog.ui" line="+17"/>
        <source>Block Data</source>
        <translation>Dati del blocco</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Block name:</source>
        <translation>Nome del Blocco:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>block 1</source>
        <translation>block 1</translation>
    </message>
    <message>
        <location filename="../BlockDialog.js" line="+115"/>
        <source>Leading or trailing spaces.</source>
        <translation>Spazi iniziali o finali.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is empty.</source>
        <translation>Nome del blocco è vuoto.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is invalid.</source>
        <translation>Nome blocco non è valido.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Block &apos;%1&apos; already exists&lt;br&gt;and will be overwritten.</source>
        <translation>Block &quot;%1&quot; esiste già&lt;br&gt;e sarà sovrascritto.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block already exists.</source>
        <translation>Blocco già esistente.</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Block/ts/Block_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Block</name>
    <message>
        <location filename="../Block.js" line="+67"/>
        <source>Block Tools</source>
        <translation>Strumenti di blocco</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show block tools</source>
        <translation>Mostra gli strumenti di blocco</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Block</source>
        <translation>&amp;Blocco</translation>
    </message>
</context>
<context>
    <name>BlockDialog</name>
    <message>
        <location filename="../BlockDialog.ui" line="+17"/>
        <source>Block Data</source>
        <translation>Dati del blocco</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Block name:</source>
        <translation>Nome del Blocco:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>block 1</source>
        <translation>block 1</translation>
    </message>
    <message>
        <location filename="../BlockDialog.js" line="+134"/>
        <source>Leading or trailing spaces.</source>
        <translation>Spazi iniziali o finali.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is empty.</source>
        <translation>Nome del blocco è vuoto.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is invalid.</source>
        <translation>Nome blocco non è valido.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Block &apos;%1&apos; already exists&lt;br&gt;and will be overwritten.</source>
        <translation>Block &quot;%1&quot; esiste già&lt;br&gt;e sarà sovrascritto.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block already exists.</source>
        <translation>Blocco già esistente.</translation>
    </message>
</context>
<context>
    <name>LayoutDialog</name>
    <message>
        <source>Layout</source>
        <translation type="vanished">Layout</translation>
    </message>
    <message>
        <source>Leading or trailing spaces.</source>
        <translation type="vanished">Spazi iniziali o finali.</translation>
    </message>
    <message>
        <source>Layout name is empty.</source>
        <translation type="vanished">Nome del layout è vuoto.</translation>
    </message>
    <message>
        <source>Layout name is invalid.</source>
        <translation type="vanished">Nome layout non è valido.</translation>
    </message>
    <message>
        <source>Layout &apos;%1&apos; already exists&lt;br&gt;and will be overwritten.</source>
        <translation type="vanished">Layout &quot;%1&quot; esiste già&lt;br&gt;e sarà sovrascritto.</translation>
    </message>
    <message>
        <source>Layout already exists.</source>
        <translation type="vanished">Layout già esistente.</translation>
    </message>
    <message>
        <source>Layout Data</source>
        <translation type="vanished">Dati del layout</translation>
    </message>
    <message>
        <source>Layout name:</source>
        <translation type="vanished">Nome del layout:</translation>
    </message>
</context>
</TS>
